==> rosegarden-1.6.1.tar.bz2: rosegarden-1.6.1/src/commands/edit/ClearTriggersCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2007
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_CLEARTRIGGERSCOMMAND_H_
#define _RG_CLEARTRIGGERSCOMMAND_H_

#include "document/BasicSelectionCommand.h"
#include <qstring.h>
#include <klocale.h>




namespace Rosegarden
{

class EventSelection;


class ClearTriggersCommand : public BasicSelectionCommand
{
public:
    ClearTriggersCommand(EventSelection &selection,
                         QString name = 0) :
        BasicSelectionCommand(name ? name : getGlobalName(), selection, true),
        m_selection(&selection)
    { }

    static QString getGlobalName() {
        return i18n("&Clear Triggers");
    }

protected:
    virtual void modifySegment();

private:
    EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
};



}

#endif

==> rosegarden_19.12.orig.tar.bz2: rosegarden-19.12/src/commands/edit/ClearTriggersCommand.h <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2018 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_CLEARTRIGGERSCOMMAND_H
#define RG_CLEARTRIGGERSCOMMAND_H

#include "document/BasicSelectionCommand.h"
#include <QString>
#include <QCoreApplication>




namespace Rosegarden
{

class EventSelection;


class ClearTriggersCommand : public BasicSelectionCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::ClearTriggersCommand)

public:
    ClearTriggersCommand(EventSelection &selection,
                         QString name = nullptr) :
        BasicSelectionCommand(!name.isEmpty() ? name : getGlobalName(), selection, true),
        m_selection(&selection)
    { }

    static QString getGlobalName() {
        return tr("&Clear Triggers");
    }

protected:
    void modifySegment() override;

private:
    EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
};



}

#endif
